@@ -26,17 +26,17 @@
 // ----------------------------------------------------------------------------
 // KDE Headers
 
-#include <kio/netaccess.h>
-#include <kio/scheduler.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/scheduler.h>
 #include <kurl.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kglobal.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
 #include <kcalendarsystem.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 
 // ----------------------------------------------------------------------------
 // Project Headers
@@ -56,7 +56,7 @@ WebPriceQuote::WebPriceQuote( TQObject* _parent, const char* _name ):
   TQObject( _parent, _name )
 {
   m_financeQuoteScriptPath =
-      KGlobal::dirs()->findResource("appdata", TQString("misc/financequote.pl"));
+      TDEGlobal::dirs()->findResource("appdata", TQString("misc/financequote.pl"));
   connect(&m_filter,TQT_SIGNAL(processExited(const TQString&)),this,TQT_SLOT(slotParseQuote(const TQString&)));
 }
 
@@ -122,7 +122,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
     url = KURL::fromPathOrURL(m_source.m_url.arg(m_symbol));
 
   // If we're running a non-interactive session (with no UI), we can't
-  // use KIO::NetAccess, so we have to get our web data the old-fashioned
+  // use TDEIO::NetAccess, so we have to get our web data the old-fashioned
   // way... with 'wget'.
   //
   // Note that a 'non-interactive' session right now means only the test
@@ -141,11 +141,11 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
 
     // if we're running non-interactive, we'll need to block.
     // otherwise, just let us know when it's done.
-    KProcess::RunMode mode = KProcess::NotifyOnExit;
+    TDEProcess::RunMode mode = TDEProcess::NotifyOnExit;
     if ( ! kapp )
-      mode = KProcess::Block;
+      mode = TDEProcess::Block;
 
-    if(m_filter.start(mode, KProcess::All))
+    if(m_filter.start(mode, TDEProcess::All))
     {
       result = true;
       m_filter.resume();
@@ -180,7 +180,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
     }
     else
     {
-      emit error(KIO::NetAccess::lastErrorString());
+      emit error(TDEIO::NetAccess::lastErrorString());
       slotParseQuote(TQString());
     }
   }
@@ -199,7 +199,7 @@ bool WebPriceQuote::download(const KURL& u, TQString & target, TQWidget* window)
 {
   m_tmpFile = TQString();
 
-  // the following code taken and adapted from KIO::NetAccess::download()
+  // the following code taken and adapted from TDEIO::NetAccess::download()
   if (target.isEmpty())
   {
     KTempFile tmpFile;
@@ -211,37 +211,37 @@ bool WebPriceQuote::download(const KURL& u, TQString & target, TQWidget* window)
   dest.setPath( target );
 
 
-  // the following code taken and adapted from KIO::NetAccess::filecopyInternal()
+  // the following code taken and adapted from TDEIO::NetAccess::filecopyInternal()
   bJobOK = true; // success unless further error occurs
 
-  KIO::Scheduler::checkSlaveOnHold(true);
-  KIO::Job * job = KIO::file_copy( u, dest, -1, true, false, false );
+  TDEIO::Scheduler::checkSlaveOnHold(true);
+  TDEIO::Job * job = TDEIO::file_copy( u, dest, -1, true, false, false );
   job->setWindow (window);
   job->addMetaData("cache", "reload");  // bypass cache
-  connect( job, TQT_SIGNAL( result (KIO::Job *) ),
-           this, TQT_SLOT( slotResult (KIO::Job *) ) );
+  connect( job, TQT_SIGNAL( result (TDEIO::Job *) ),
+           this, TQT_SLOT( slotResult (TDEIO::Job *) ) );
 
   enter_loop();
   return bJobOK;
 
 }
 
-// The following parts are copied and adjusted from KIO::NetAccess
+// The following parts are copied and adjusted from TDEIO::NetAccess
 
 // If a troll sees this, he kills me
-void qt_enter_modal( TQWidget *widget );
-void qt_leave_modal( TQWidget *widget );
+void tqt_enter_modal( TQWidget *widget );
+void tqt_leave_modal( TQWidget *widget );
 
 void WebPriceQuote::enter_loop(void)
 {
   TQWidget dummy(0,0,WType_Dialog | WShowModal);
   dummy.setFocusPolicy( TQ_NoFocus );
-  qt_enter_modal(&dummy);
+  tqt_enter_modal(&dummy);
   tqApp->enter_loop();
-  qt_leave_modal(&dummy);
+  tqt_leave_modal(&dummy);
 }
 
-void WebPriceQuote::slotResult( KIO::Job * job )
+void WebPriceQuote::slotResult( TDEIO::Job * job )
 {
   lastErrorCode = job->error();
   bJobOK = !job->error();
@@ -254,7 +254,7 @@ void WebPriceQuote::slotResult( KIO::Job * job )
 
   tqApp->exit_loop();
 }
-// The above parts are copied and adjusted from KIO::NetAccess
+// The above parts are copied and adjusted from TDEIO::NetAccess
 
 bool WebPriceQuote::launchFinanceQuote ( const TQString& _symbol, const TQString& _id,
                                const TQString& _sourcename ) {
@@ -272,18 +272,18 @@ bool WebPriceQuote::launchFinanceQuote ( const TQString& _symbol, const TQString
 
 
   m_filter.clearArguments();
-  m_filter << "perl" << m_financeQuoteScriptPath << FTQSource << KProcess::quote(_symbol);
+  m_filter << "perl" << m_financeQuoteScriptPath << FTQSource << TDEProcess::quote(_symbol);
   m_filter.setUseShell(true);
   m_filter.setSymbol(m_symbol);
   emit status(TQString("Executing %1 %2 %3...").arg(m_financeQuoteScriptPath).arg(FTQSource).arg(_symbol));
 
     // if we're running non-interactive, we'll need to block.
     // otherwise, just let us know when it's done.
-  KProcess::RunMode mode = KProcess::NotifyOnExit;
+  TDEProcess::RunMode mode = TDEProcess::NotifyOnExit;
   if ( ! kapp )
-    mode = KProcess::Block;
+    mode = TDEProcess::Block;
 
-  if(m_filter.start(mode, KProcess::All))
+  if(m_filter.start(mode, TDEProcess::All))
   {
     result = true;
     m_filter.resume();
@@ -598,8 +598,8 @@ TQStringList WebPriceQuote::quoteSources (const _quoteSystemE _system) {
 
 TQStringList WebPriceQuote::quoteSourcesNative()
 {
-  KConfig *kconfig = KGlobal::config();
-  TQStringList groups = kconfig->groupList();
+  TDEConfig *tdeconfig = TDEGlobal::config();
+  TQStringList groups = tdeconfig->groupList();
 
   TQStringList::Iterator it;
   TQRegExp onlineQuoteSource(TQString("^Online-Quote-Source-(.*)$"));
@@ -614,23 +614,23 @@ TQStringList WebPriceQuote::quoteSourcesNative()
 
   // if the user has the OLD quote source defined, now is the
   // time to remove that entry and convert it to the new system.
-  if ( ! groups.count() && kconfig->hasGroup("Online Quotes Options") )
+  if ( ! groups.count() && tdeconfig->hasGroup("Online Quotes Options") )
   {
-    kconfig->setGroup("Online Quotes Options");
-    TQString url(kconfig->readEntry("URL","http://finance.yahoo.com/d/quotes.csv?s=%1&f=sl1d1"));
-    TQString symbolRegExp(kconfig->readEntry("SymbolRegex","\"([^,\"]*)\",.*"));
-    TQString priceRegExp(kconfig->readEntry("PriceRegex","[^,]*,([^,]*),.*"));
-    TQString dateRegExp(kconfig->readEntry("DateRegex","[^,]*,[^,]*,\"([^\"]*)\""));
-    kconfig->deleteGroup("Online Quotes Options");
+    tdeconfig->setGroup("Online Quotes Options");
+    TQString url(tdeconfig->readEntry("URL","http://finance.yahoo.com/d/quotes.csv?s=%1&f=sl1d1"));
+    TQString symbolRegExp(tdeconfig->readEntry("SymbolRegex","\"([^,\"]*)\",.*"));
+    TQString priceRegExp(tdeconfig->readEntry("PriceRegex","[^,]*,([^,]*),.*"));
+    TQString dateRegExp(tdeconfig->readEntry("DateRegex","[^,]*,[^,]*,\"([^\"]*)\""));
+    tdeconfig->deleteGroup("Online Quotes Options");
 
     groups += "Old Source";
-    kconfig->setGroup(TQString("Online-Quote-Source-%1").arg("Old Source"));
-    kconfig->writeEntry("URL", url);
-    kconfig->writeEntry("SymbolRegex", symbolRegExp);
-    kconfig->writeEntry("PriceRegex",priceRegExp);
-    kconfig->writeEntry("DateRegex", dateRegExp);
-    kconfig->writeEntry("DateFormatRegex", "%m %d %y");
-    kconfig->sync();
+    tdeconfig->setGroup(TQString("Online-Quote-Source-%1").arg("Old Source"));
+    tdeconfig->writeEntry("URL", url);
+    tdeconfig->writeEntry("SymbolRegex", symbolRegExp);
+    tdeconfig->writeEntry("PriceRegex",priceRegExp);
+    tdeconfig->writeEntry("DateRegex", dateRegExp);
+    tdeconfig->writeEntry("DateFormatRegex", "%m %d %y");
+    tdeconfig->sync();
   }
 
   // Set up each of the default sources.  These are done piecemeal so that
@@ -643,7 +643,7 @@ TQStringList WebPriceQuote::quoteSourcesNative()
     {
       groups += (*it_source).m_name;
       (*it_source).write();
-      kconfig->sync();
+      tdeconfig->sync();
     }
     ++it_source;
   }
@@ -656,7 +656,7 @@ TQStringList WebPriceQuote::quoteSourcesFinanceQuote()
   if (m_financeQuoteSources.empty()) { // run the process one time only
     FinanceQuoteProcess getList;
     m_financeQuoteScriptPath =
-        KGlobal::dirs()->findResource("appdata", TQString("misc/financequote.pl"));
+        TDEGlobal::dirs()->findResource("appdata", TQString("misc/financequote.pl"));
     getList.launch( m_financeQuoteScriptPath );
     while (!getList.isFinished()) {
       tqApp->processEvents();
@@ -683,29 +683,29 @@ WebPriceQuoteSource::WebPriceQuoteSource(const TQString& name, const TQString& u
 WebPriceQuoteSource::WebPriceQuoteSource(const TQString& name)
 {
   m_name = name;
-  KConfig *kconfig = KGlobal::config();
-  kconfig->setGroup(TQString("Online-Quote-Source-%1").arg(m_name));
-  m_sym = kconfig->readEntry("SymbolRegex");
-  m_date = kconfig->readEntry("DateRegex");
-  m_dateformat = kconfig->readEntry("DateFormatRegex","%m %d %y");
-  m_price = kconfig->readEntry("PriceRegex");
-  m_url = kconfig->readEntry("URL");
-  m_skipStripping = kconfig->readBoolEntry("SkipStripping", false);
+  TDEConfig *tdeconfig = TDEGlobal::config();
+  tdeconfig->setGroup(TQString("Online-Quote-Source-%1").arg(m_name));
+  m_sym = tdeconfig->readEntry("SymbolRegex");
+  m_date = tdeconfig->readEntry("DateRegex");
+  m_dateformat = tdeconfig->readEntry("DateFormatRegex","%m %d %y");
+  m_price = tdeconfig->readEntry("PriceRegex");
+  m_url = tdeconfig->readEntry("URL");
+  m_skipStripping = tdeconfig->readBoolEntry("SkipStripping", false);
 }
 
 void WebPriceQuoteSource::write(void) const
 {
-  KConfig *kconfig = KGlobal::config();
-  kconfig->setGroup(TQString("Online-Quote-Source-%1").arg(m_name));
-  kconfig->writeEntry("URL", m_url);
-  kconfig->writeEntry("PriceRegex", m_price);
-  kconfig->writeEntry("DateRegex", m_date);
-  kconfig->writeEntry("DateFormatRegex", m_dateformat);
-  kconfig->writeEntry("SymbolRegex", m_sym);
+  TDEConfig *tdeconfig = TDEGlobal::config();
+  tdeconfig->setGroup(TQString("Online-Quote-Source-%1").arg(m_name));
+  tdeconfig->writeEntry("URL", m_url);
+  tdeconfig->writeEntry("PriceRegex", m_price);
+  tdeconfig->writeEntry("DateRegex", m_date);
+  tdeconfig->writeEntry("DateFormatRegex", m_dateformat);
+  tdeconfig->writeEntry("SymbolRegex", m_sym);
   if(m_skipStripping)
-    kconfig->writeEntry("SkipStripping", m_skipStripping);
+    tdeconfig->writeEntry("SkipStripping", m_skipStripping);
   else
-    kconfig->deleteEntry("SkipStripping");
+    tdeconfig->deleteEntry("SkipStripping");
 }
 
 void WebPriceQuoteSource::rename(const TQString& name)
@@ -717,21 +717,21 @@ void WebPriceQuoteSource::rename(const TQString& name)
 
 void WebPriceQuoteSource::remove(void) const
 {
-  KConfig *kconfig = KGlobal::config();
-  kconfig->deleteGroup(TQString("Online-Quote-Source-%1").arg(m_name));
+  TDEConfig *tdeconfig = TDEGlobal::config();
+  tdeconfig->deleteGroup(TQString("Online-Quote-Source-%1").arg(m_name));
 }
 
 //
-// Helper class to babysit the KProcess used for running the local script in that case
+// Helper class to babysit the TDEProcess used for running the local script in that case
 //
 
 WebPriceQuoteProcess::WebPriceQuoteProcess(void)
 {
-  connect(this, TQT_SIGNAL(receivedStdout(KProcess*, char*, int)), this, TQT_SLOT(slotReceivedDataFromFilter(KProcess*, char*, int)));
-  connect(this, TQT_SIGNAL(processExited(KProcess*)), this, TQT_SLOT(slotProcessExited(KProcess*)));
+  connect(this, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(slotReceivedDataFromFilter(TDEProcess*, char*, int)));
+  connect(this, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotProcessExited(TDEProcess*)));
 }
 
-void WebPriceQuoteProcess::slotReceivedDataFromFilter(KProcess* /*_process*/, char* _pcbuffer, int _nbufferlen)
+void WebPriceQuoteProcess::slotReceivedDataFromFilter(TDEProcess* /*_process*/, char* _pcbuffer, int _nbufferlen)
 {
   TQByteArray data;
   data.duplicate(_pcbuffer, _nbufferlen);
@@ -740,7 +740,7 @@ void WebPriceQuoteProcess::slotReceivedDataFromFilter(KProcess* /*_process*/, ch
   m_string += TQString(data);
 }
 
-void WebPriceQuoteProcess::slotProcessExited(KProcess*)
+void WebPriceQuoteProcess::slotProcessExited(TDEProcess*)
 {
 //   kdDebug(2) << "WebPriceQuoteProcess::slotProcessExited()" << endl;
   emit processExited(m_string);
@@ -748,7 +748,7 @@ void WebPriceQuoteProcess::slotProcessExited(KProcess*)
 }
 
 //
-// Helper class to babysit the KProcess used for running the Finance Quote sources script
+// Helper class to babysit the TDEProcess used for running the Finance Quote sources script
 //
 
 FinanceQuoteProcess::FinanceQuoteProcess(void)
@@ -809,11 +809,11 @@ FinanceQuoteProcess::FinanceQuoteProcess(void)
   m_fqNames["yahoo_europe"] = "Yahoo Europe";
   m_fqNames["yahoo_nz"] = "Yahoo New Zealand";
   m_fqNames["zifunds"] = "Zuerich Investments";
-  connect(this, TQT_SIGNAL(receivedStdout(KProcess*, char*, int)), this, TQT_SLOT(slotReceivedDataFromFilter(KProcess*, char*, int)));
-  connect(this, TQT_SIGNAL(processExited(KProcess*)), this, TQT_SLOT(slotProcessExited(KProcess*)));
+  connect(this, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(slotReceivedDataFromFilter(TDEProcess*, char*, int)));
+  connect(this, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotProcessExited(TDEProcess*)));
 }
 
-void FinanceQuoteProcess::slotReceivedDataFromFilter(KProcess* /*_process*/, char* _pcbuffer, int _nbufferlen)
+void FinanceQuoteProcess::slotReceivedDataFromFilter(TDEProcess* /*_process*/, char* _pcbuffer, int _nbufferlen)
 {
   TQByteArray data;
   data.duplicate(_pcbuffer, _nbufferlen);
@@ -822,7 +822,7 @@ void FinanceQuoteProcess::slotReceivedDataFromFilter(KProcess* /*_process*/, cha
   m_string += TQString(data);
 }
 
-void FinanceQuoteProcess::slotProcessExited(KProcess*)
+void FinanceQuoteProcess::slotProcessExited(TDEProcess*)
 {
 //   kdDebug(2) << "WebPriceQuoteProcess::slotProcessExited()" << endl;
   m_isDone = true;
@@ -833,7 +833,7 @@ void FinanceQuoteProcess::launch (const TQString& scriptPath) {
   arguments.append(TQCString("perl"));
   arguments.append (TQCString(scriptPath));
   arguments.append (TQCString("-l"));
-  if (!start(KProcess::NotifyOnExit, KProcess::Stdout)) qFatal ("Unable to start FQ script");
+  if (!start(TDEProcess::NotifyOnExit, TDEProcess::Stdout)) tqFatal ("Unable to start FQ script");
   return;
 }
 
@@ -950,8 +950,8 @@ TQDate MyMoneyDateFormat::convertString(const TQString& _in, bool _strict, unsig
         unsigned i = 1;
         while ( i <= 12 )
         {
-          if(KGlobal::locale()->calendar()->monthName(i, 2000, true).lower() == *it_scanned
-          || KGlobal::locale()->calendar()->monthName(i, 2000, false).lower() == *it_scanned)
+          if(TDEGlobal::locale()->calendar()->monthName(i, 2000, true).lower() == *it_scanned
+          || TDEGlobal::locale()->calendar()->monthName(i, 2000, false).lower() == *it_scanned)
             month = i;
           ++i;
         }
@@ -1044,7 +1044,4 @@ void convertertest::QuoteReceiver::slotError(const TQString& msg)
 
   m_errors += msg;
 }
-
-// vim:cin:si:ai:et:ts=2:sw=2:
-
 #include "webpricequote.moc"
