@@ -30,10 +30,10 @@
 // KDE Includes
 
 #include <ktextedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcombobox.h>
 #include <kpushbutton.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kstdguiitem.h>
 
 // ----------------------------------------------------------------------------
@@ -362,7 +362,7 @@ int InvestTransactionEditor::editSplits(const TQString& categoryWidgetName, cons
       d->m_phonyAccount.setCurrencyId(m_transaction.commodity());
       d->m_phonyAccount.fraction(MyMoneyFile::instance()->security(m_transaction.commodity()));
     } catch(MyMoneyException *e) {
-      qDebug("Unable to setup precision");
+      tqDebug("Unable to setup precision");
       delete e;
     }
 
