@@ -23,9 +23,9 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kactivelabel.h>
 
 // ----------------------------------------------------------------------------
@@ -122,7 +122,7 @@ KEndingBalanceDlg::KEndingBalanceDlg(const MyMoneyAccount& account, TQWidget *pa
   m_lastStatementDate->setText(TQString());
   if(account.lastReconciliationDate().isValid()) {
     m_lastStatementDate->setText(i18n("Last reconciled statement: %1")
-      .arg(KGlobal::locale()->formatDate(account.lastReconciliationDate(), true)));
+      .arg(TDEGlobal::locale()->formatDate(account.lastReconciliationDate(), true)));
   }
 
   // remove all unwanted pages
@@ -362,7 +362,7 @@ bool KEndingBalanceDlg::createTransaction(MyMoneyTransaction &t, const int sign,
     t.modifySplit(s2);
 
   } catch(MyMoneyException *e) {
-    qDebug("%s", e->what().data());
+    tqDebug("%s", e->what().data());
     delete e;
     t = MyMoneyTransaction();
     return false;
@@ -510,8 +510,8 @@ void KEndingBalanceLoanDlg::next(void)
     m_loanOverview->setText(i18n("KMyMoney has calculated the following amounts for "
                                  "interest and amortization according to recorded payments "
                                  "between %1 and %2.")
-                                 .arg(KGlobal::locale()->formatDate(m_startDateEdit->date(), true))
-                                 .arg(KGlobal::locale()->formatDate(m_endDateEdit->date(), true)));
+                                 .arg(TDEGlobal::locale()->formatDate(m_startDateEdit->date(), true))
+                                 .arg(TDEGlobal::locale()->formatDate(m_endDateEdit->date(), true)));
 
     // preload widgets with calculated values if they are empty
     if(m_amortizationTotalEdit->value().isZero() && !amortization.isZero())
@@ -590,7 +590,7 @@ const MyMoneyTransaction KEndingBalanceLoanDlg::adjustmentTransaction(void) cons
       t.setPostDate(m_endDateEdit->date());
 
     } catch(MyMoneyException *e) {
-      qDebug("Unable to create adjustment transaction for loan reconciliation: %s", e->what().data());
+      tqDebug("Unable to create adjustment transaction for loan reconciliation: %s", e->what().data());
       delete e;
       return MyMoneyTransaction();
     }
