@@ -34,10 +34,10 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <kglobal.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
 #include <kpushbutton.h>
 #include <kiconloader.h>
 #include <kguiitem.h>
@@ -61,8 +61,8 @@
 #include "../kmymoney2.h"
 
 // *** KBudgetListItem Implementation ***
-KBudgetListItem::KBudgetListItem(KListView *parent, const MyMoneyBudget& budget) :
-  KListViewItem(parent),
+KBudgetListItem::KBudgetListItem(TDEListView *parent, const MyMoneyBudget& budget) :
+  TDEListViewItem(parent),
   m_budget(budget)
 {
   setText(0, budget.name());
@@ -103,44 +103,44 @@ KBudgetView::KBudgetView(TQWidget *parent, const char *name ) :
   m_accountTree->setSorting(-1);
   m_budgetList->setSorting(0);
 
-  KIconLoader* il = KGlobal::iconLoader();
+  TDEIconLoader* il = TDEGlobal::iconLoader();
   KGuiItem newButtenItem( TQString(""),
-                             TQIconSet(il->loadIcon("file_new", KIcon::Small, KIcon::SizeSmall)),
+                             TQIconSet(il->loadIcon("file_new", TDEIcon::Small, TDEIcon::SizeSmall)),
                              i18n("Creates a new budget"),
                              i18n("Use this to create a new empty budget."));
   m_newButton->setGuiItem(newButtenItem);
   TQToolTip::add(m_newButton, newButtenItem.toolTip());
 
   KGuiItem renameButtenItem( TQString(""),
-                          TQIconSet(il->loadIcon("editpaste", KIcon::Small, KIcon::SizeSmall)),
+                          TQIconSet(il->loadIcon("edit-paste", TDEIcon::Small, TDEIcon::SizeSmall)),
                           i18n("Rename the current selected budget"),
                           i18n("Use this to start renaming the selected budget."));
   m_renameButton->setGuiItem(renameButtenItem);
   TQToolTip::add(m_renameButton, renameButtenItem.toolTip());
 
   KGuiItem deleteButtenItem( TQString(""),
-                             TQIconSet(il->loadIcon("editdelete", KIcon::Small, KIcon::SizeSmall)),
+                             TQIconSet(il->loadIcon("edit-delete", TDEIcon::Small, TDEIcon::SizeSmall)),
                              i18n("Delete the current selected budget"),
                              i18n("Use this to delete the selected budget."));
   m_deleteButton->setGuiItem(deleteButtenItem);
   TQToolTip::add(m_deleteButton, deleteButtenItem.toolTip());
 
   KGuiItem updateButtenItem( TQString(""),
-                             TQIconSet(il->loadIcon("button_ok", KIcon::Small, KIcon::SizeSmall)),
+                             TQIconSet(il->loadIcon("button_ok", TDEIcon::Small, TDEIcon::SizeSmall)),
                              i18n("Accepts the entered values and stores the budget"),
                              i18n("Use this to store the modified data."));
   m_updateButton->setGuiItem(updateButtenItem);
   TQToolTip::add(m_updateButton, updateButtenItem.toolTip());
 
   KGuiItem resetButtenItem( TQString(""),
-                             TQIconSet(il->loadIcon("undo", KIcon::Small, KIcon::SizeSmall)),
+                             TQIconSet(il->loadIcon("edit-undo", TDEIcon::Small, TDEIcon::SizeSmall)),
                              i18n("Revert budget to last saved state"),
                              i18n("Use this to discard the modified data."));
   m_resetButton->setGuiItem(resetButtenItem);
   TQToolTip::add(m_resetButton, resetButtenItem.toolTip());
 
-  connect(m_budgetList, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem* , const TQPoint&)),
-    this, TQT_SLOT(slotOpenContextMenu(KListView*, TQListViewItem*, const TQPoint&)));
+  connect(m_budgetList, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem* , const TQPoint&)),
+    this, TQT_SLOT(slotOpenContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
   connect(m_budgetList, TQT_SIGNAL(itemRenamed(TQListViewItem*,int,const TQString&)), this, TQT_SLOT(slotRenameBudget(TQListViewItem*,int,const TQString&)));
   connect(m_budgetList, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(slotSelectBudget()));
 
@@ -562,7 +562,7 @@ KMyMoneyAccountTreeBudgetItem* KBudgetView::selectedAccount(void) const
   return item;
 }
 
-void KBudgetView::slotOpenContextMenu(KListView* lv, TQListViewItem* i, const TQPoint& p)
+void KBudgetView::slotOpenContextMenu(TDEListView* lv, TQListViewItem* i, const TQPoint& p)
 {
   Q_UNUSED(lv);
   Q_UNUSED(p);
